#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 idris
version:              1.3.3
visibility:           public
id:                   idris-1.3.3-LgEKUygSaCNJShA5CB3k3g
key:                  idris-1.3.3-LgEKUygSaCNJShA5CB3k3g
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  9d903b4330e6edfb7b388370c0dd3aaf
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-8.10.5/site-local/idris-1.3.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/idris-1.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.3-LgEKUygSaCNJShA5CB3k3g
extra-libraries:      gmp
depends:
    aeson-1.5.6.0-6uunGgFAYkLL5zoDUTK2GY
    annotated-wl-pprint-0.7.0-LfvIEL94sD0ER9mdrVDak7
    ansi-terminal-0.11-KZlfwqvn41oLlRmR1M9CEn
    ansi-wl-pprint-0.6.9-4Mzh6BhiCVpFwrCWKH3P3O array-0.5.4.0
    async-2.2.3-HtWYxLW2ntnKBaQHYE7IJT base-4.14.2.0
    base64-bytestring-1.2.0.1-6PvrigrzgN5CFxMJsxx0QP binary-0.8.8.0
    blaze-html-0.9.1.2-7YURpfDATS7FKWEku5NEG5
    blaze-markup-0.8.2.8-7y6za9FDoBHA9fX5ZL40tI bytestring-0.10.12.0
    cheapskate-0.1.1.2-Ev33eVu0Pp73v9CUQ527km
    code-page-0.2.1-3C62FJxRFEL4hMDYNXOvWB containers-0.6.4.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1
    fingertree-0.1.4.2-AmccQaGr7nu5BkutGe38Yh
    fsnotify-0.3.0.1-Gu1HeeovJr8EpU9XZ93JWy haskeline-0.8.0.1
    ieee754-0.8.0-CHSaaJtgXtAIvy6hnwP5XY
    libffi-0.1-8U8n8AdfLs66HXhD0Pbsc9
    megaparsec-9.0.1-AZ4QZpeqwBO60zdWzkd9AU mtl-2.2.2
    network-3.1.2.2-25lMYs5jWh9BSaCkMt8wPK
    optparse-applicative-0.16.1.0-I5IUJeu2M04AGs6xg5A1ij
    parser-combinators-1.3.0-I56cvBuZMEG2VbjtPZAqZY pretty-1.1.3.6
    process-1.6.9.0 regex-tdfa-1.3.1.1-GKHvEQcFLVkJ8X6kzhWyIo
    safe-0.3.19-DlKvqLTtraZKItu5PR3KBM
    split-0.2.3.4-2CazDyCwHVY5SBexdl3uQN
    terminal-size-0.3.2.1-8LMlp57ywuCIM7VIh4tqn1 text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-F0Ji7d4bSq610MEw5CyoNb unix-2.7.2.2
    unordered-containers-0.2.14.0-1OFWlQlrCvvLaIazZ0Uw3i
    utf8-string-1.0.2-DMovLmOdbFr3ZT2kNNb9Du
    vector-0.12.3.0-EcRb4NXFUGH91vV3xG3jJs
    vector-binary-instances-0.2.5.2-74z48scPqNeHJt3mTnQEjW
    zip-archive-0.4.1-FaICFShsbXA9AVhi0vGREU

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

